@@ -1,5 +1,5 @@
 """
-**yodel** (*the Swiss Army knife or your sound*) is an easy-to-use python
+**yodel** (*the Swiss Army knife of your sound*) is an easy-to-use python
 package for digital audio signal processing, analysis and synthesis.
 """
 
@@ -7,7 +7,7 @@ __author__ = 'Romain Clement'
 __copyright__ = 'Copyright 2014, Romain Clement'
 __credits__ = []
 __license__ = 'MIT'
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 __maintainer__ = 'Romain Clement'
 __email__ = 'contact@romainclement.com'
 __status__ = 'Development'
